@@ -3,6 +3,12 @@
 set -e
 
 
+if [ "${1}" = "--version" ]; then
+  echo "0.1.6"
+  exit 0
+fi
+
+
 NAME="${1}"
 TYPE="${2}"
 if [ -z "${NAME}" -o -z "${TYPE}" ]; then
@@ -12,7 +18,6 @@ fi
 
 
 PROJECT_ROOT=`python${PY_VERSION} -c 'import os; import freenit; print(os.path.dirname(os.path.abspath(freenit.__file__)))'`
-echo "here"
 SED_CMD="sed -i"
 
 case `uname` in
