@@ -1,12 +1,13 @@
 import sys
 from importlib import import_module
 
-import freenit.schemas.user
 from flask import Flask, send_file
 from flask_collect import Collect
 from flask_cors import CORS
 from flask_jwt_extended import JWTManager
 from flask_security import Security
+
+import freenit.schemas.user
 from freenit.schemas.paging import PageOutSchema
 
 from . import cli
@@ -19,8 +20,14 @@ def sqlinit(app):
     from .db import db
     db.init_app(app)
     app.db = db
-    User = import_module(f"{app.config['NAME']}.models.sql.user").User
-    role_module = import_module(f"{app.config['NAME']}.models.sql.role")
+    try:
+        User = import_module(f"{app.config['NAME']}.models.sql.user").User
+    except ModuleNotFoundError:
+        User = import_module(f"{app.config['NAME']}.models.user").User
+    try:
+        role_module = import_module(f"{app.config['NAME']}.models.role")
+    except ModuleNotFoundError:
+        role_module = import_module(f"{app.config['NAME']}.models.sql.role")
     Role = role_module.Role
     UserRoles = role_module.UserRoles
     app.user_datastore = PeeweeUserDatastore(
@@ -35,8 +42,14 @@ def mongoinit(app):
     from flask_security import MongoEngineUserDatastore
     from flask_mongoengine import MongoEngine
     app.db = MongoEngine(app)
-    User = import_module(f"{app.config['NAME']}.models.mongo.user").User
-    Role = import_module(f"{app.config['NAME']}.models.mongo.role").Role
+    try:
+        User = import_module(f"{app.config['NAME']}.models.user").User
+    except ModuleNotFoundError:
+        User = import_module(f"{app.config['NAME']}.models.mongo.user").User
+    try:
+        Role = import_module(f"{app.config['NAME']}.models.role").Role
+    except ModuleNotFoundError:
+        Role = import_module(f"{app.config['NAME']}.models.mongo.role").Role
     app.user_datastore = MongoEngineUserDatastore(app.db, User, Role)
 
 
@@ -56,7 +69,7 @@ def create_app(config, app=None, schemas={}, dbtype='sql'):
     app.sendmail = lambda message: sendmail(app.config, message)
     app.collect = Collect(app)
     app.dbtype = dbtype
-    if dbtype == 'sql':
+    if dbtype in ['sql', 'all']:
         sqlinit(app)
     elif dbtype == 'mongo':
         mongoinit(app)
